==> qtjambi-qml-jre8-6.2-sources.jar: io/qt/qml/QQmlPropertyValueSource.java <==
package io.qt.qml;


/**
 * <p>Interface for property value sources such as animations and bindings</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html">QQmlPropertyValueSource</a></p>
 */
public interface QQmlPropertyValueSource extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.qml.QQmlPropertyValueSource}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qml.QQmlPropertyValueSource
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QQmlPropertyValueSource.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public void setTarget(io.qt.qml.QQmlProperty arg__1){
                setTarget_native_cref_QQmlProperty(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
            }
            private native static void setTarget_native_cref_QQmlProperty(long __this__nativeId, long arg__1);
            
        }
        
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#QQmlPropertyValueSource">QQmlPropertyValueSource::</a></p>
         */
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QQmlPropertyValueSource instance);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#setTarget">QQmlPropertyValueSource::</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setTarget(io.qt.qml.QQmlProperty arg__1);
        
        private native static void setTarget_native_cref_QQmlProperty(long __this__nativeId, long arg__1);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#setTarget">QQmlPropertyValueSource::setTarget(QQmlProperty)</a></p>
     */
    @io.qt.QtUninvokable
    public void setTarget(io.qt.qml.QQmlProperty arg__1);
    
}

==> qtjambi-qml-jre8-6.2.3-sources.jar: io/qt/qml/QQmlPropertyValueSource.java <==
package io.qt.qml;


/**
 * <p>Interface for property value sources such as animations and bindings</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html">QQmlPropertyValueSource</a></p>
 */
public interface QQmlPropertyValueSource extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.qml.QQmlPropertyValueSource}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qml.QQmlPropertyValueSource
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QQmlPropertyValueSource.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public void setTarget(io.qt.qml.QQmlProperty arg__1){
                setTarget_native_cref_QQmlProperty(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
            }
            private native static void setTarget_native_cref_QQmlProperty(long __this__nativeId, long arg__1);
            
        }
        
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#QQmlPropertyValueSource">QQmlPropertyValueSource::QQmlPropertyValueSource()</a></p>
         */
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QQmlPropertyValueSource instance);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#setTarget">QQmlPropertyValueSource::setTarget(QQmlProperty)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setTarget(io.qt.qml.QQmlProperty arg__1);
        
        private native static void setTarget_native_cref_QQmlProperty(long __this__nativeId, long arg__1);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qqmlpropertyvaluesource.html#setTarget">QQmlPropertyValueSource::setTarget(QQmlProperty)</a></p>
     */
    @io.qt.QtUninvokable
    public void setTarget(io.qt.qml.QQmlProperty arg__1);
    
}
